@@ -58,18 +58,6 @@ OC.L10N.register(
     "Add group or team" : "Aggiungi gruppo o team",
     "{size} used" : "{size} utilizzati",
     "Other …" : "Altro...",
-    "You can not remove your own read permission." : "Non puoi rimuovere la tua autorizzazione di lettura.",
-    "Group folders" : "Cartelle di gruppo",
-    "Admin configured folders shared with everyone in a group" : "Cartelle configurate dagli amministratori condivise con chiunque in un gruppo",
-    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Cartelle configurate dall'amministratore e condivise con tutti i membri di un gruppo. \n\nLe cartelle possono essere configurate da *Cartelle di gruppo* in impostazioni di amministratore. \n\nDopo aver creato una cartella, l'amministratore può concedere l'accesso alla cartella a uno o più gruppi, controllare i loro permessi di scrittura/condivisione e assegnare una quota per la cartella.",
-    "Group folder" : "Cartella di gruppo",
-    "Open group folder" : "Apri cartella di gruppo",
-    "List of group folders." : "Elenco delle cartelle di gruppo.",
-    "No group folders yet" : "Nessuna cartella di gruppo ",
-    "Group folders will show up here" : "Le cartelle di gruppo verranno visualizzate qui",
-    "Group folder admin delegation" : "Delega amministratore cartella di gruppo",
-    "They will have access to all group folders." : "Avranno accesso a tutte le cartelle del gruppo.",
-    "They will only have access to group folders for which they have advanced permissions." : "Avranno accesso solo alle cartelle di gruppo per le quali dispongono di autorizzazioni avanzate.",
     "Admin configured folders shared with everyone in a team" : "Cartelle configurate dall'amministratore condivise con tutti i membri di un team",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Cartelle configurate dall'amministratore condivise con tutti in un team.\n\nLe cartelle possono essere configurate da *Cartelle del team* nelle impostazioni dell'amministratore.\n\nDopo aver creato una cartella, l'amministratore può concedere l'accesso alla cartella a uno o più team, controllare i loro permessi di scrittura/condivisione e assegnare una quota per la cartella.",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Cartelle configurate dall'amministratore condivise con tutti in un team.\n\nLe cartelle possono essere configurate da *Cartelle team* nelle impostazioni dell'amministratore.\n\nDopo aver creato una cartella, l'amministratore può concedere l'accesso alla cartella a uno o più team, controllare i loro permessi di scrittura/condivisione e assegnare una quota per la cartella.\nA partire da Hub 10/Nextcloud 31, l'amministratore deve far parte del team per potergli assegnare una cartella Team."
