@@ -16,24 +16,21 @@ use Psr\Log\LoggerInterface;
 
 class ACLManagerFactory {
 	public function __construct(
-		private RuleManager $ruleManager,
-		private TrashManager $trashManager,
-		private IAppConfig $config,
-		private LoggerInterface $logger,
-		private IUserMappingManager $userMappingManager,
-		private \Closure $rootFolderProvider,
+		private readonly RuleManager $ruleManager,
+		private readonly TrashManager $trashManager,
+		private readonly IAppConfig $config,
+		private readonly LoggerInterface $logger,
+		private readonly IUserMappingManager $userMappingManager,
 	) {
 	}
 
-	public function getACLManager(IUser $user, ?int $rootStorageId = null): ACLManager {
+	public function getACLManager(IUser $user): ACLManager {
 		return new ACLManager(
 			$this->ruleManager,
 			$this->trashManager,
 			$this->userMappingManager,
 			$this->logger,
 			$user,
-			$this->rootFolderProvider,
-			$rootStorageId,
 			$this->config->getValueString('groupfolders', 'acl-inherit-per-user', 'false') === 'true',
 		);
 	}
