@@ -33,7 +33,7 @@ class Delete extends FolderCommand {
 		$helper = $this->getHelper('question');
 		$question = new ConfirmationQuestion('Are you sure you want to delete the Team folder ' . $folder->mountPoint . ' and all files within, this cannot be undone (y/N).', false);
 		if ($input->getOption('force') || $helper->ask($input, $output, $question)) {
-			$this->folderStorageManager->deleteStoragesForFolder($folder->id);
+			$this->folderStorageManager->deleteStoragesForFolder($folder);
 			$this->folderManager->removeFolder($folder->id);
 		}
 
