@@ -1,4 +1,6 @@
 <?php
+
+declare (strict_types=1);
 /**
  * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -13,8 +15,8 @@ use OCP\Settings\IIconSection;
 
 class Section implements IIconSection {
 	public function __construct(
-		private IL10N $l,
-		private IURLGenerator $url,
+		private readonly IL10N $l,
+		private readonly IURLGenerator $url,
 	) {
 	}
 
